@@ -551,7 +551,7 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
       if (UNLIKELY(var == NULL)) {
         synterr(csound, Str("Variable '%s' used before defined\n"
                             "Line %d\n"),
-                tree->value->lexeme, tree->line);
+                tree->value->lexeme, tree->line-1); /* -1 as read next line! */
         do_baktrace(csound, tree->locn);
         return NULL;
       }
@@ -560,7 +560,7 @@ char* get_arg_type2(CSOUND* csound, TREE* tree, TYPE_TABLE* typeTable)
         char *res = create_array_arg_type(csound, var);
         if (res==NULL) {        /* **REVIEW** this double syntax error */
           synterr(csound, Str("Array of unknown type\n"));
-          csoundMessage(csound, Str("Line: %d\n"), tree->line);
+          csoundMessage(csound, Str("Line: %d\n"), tree->line-1);
           do_baktrace(csound, tree->locn);
         }
         return res;
@@ -616,7 +616,6 @@ char* get_opcode_short_name(CSOUND* csound, char* opname) {
 
 /* find opcode with the specified name in opcode list */
 /* returns index to opcodlst[], or zero if the opcode cannot be found */
-
 OENTRY* find_opcode(CSOUND *csound, char *opname)
 {
     char *shortName;
@@ -632,7 +631,6 @@ OENTRY* find_opcode(CSOUND *csound, char *opname)
 
     retVal = (head != NULL) ? head->value : NULL;
     if (shortName != opname) csound->Free(csound, shortName);
-
     return retVal;
 }
 
@@ -1165,6 +1163,8 @@ OENTRY* find_opcode_new(CSOUND* csound, char* opname,
 
     csound->Free(csound, opcodes);
 
+
+
     return retVal;
 }
 
@@ -1770,9 +1770,6 @@ TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
     CONS_CELL* parentLabelList = typeTable->labelList;
     typeTable->labelList = get_label_list(csound, root);
 
-    //if (root->value)
-    //printf("###verify %p %p (%s)\n", root, root->value, root->value->lexeme);
-
     if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "Verifying AST\n");
 
     while (current != NULL) {
@@ -1802,7 +1799,8 @@ TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
         break;
       case UDO_TOKEN:
         csound->inZero = 0;
-        if (UNLIKELY(PARSER_DEBUG)) csound->Message(csound, "UDO found\n");
+        if (UNLIKELY(PARSER_DEBUG))
+          csound->Message(csound, "UDO found\n");
 
         typeTable->localPool = csoundCreateVarPool(csound);
         current->markup = typeTable->localPool;
@@ -1848,10 +1846,12 @@ TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
         if (!verify_until_statement(csound, current, typeTable)) {
           return 0;
         }
-
+/* #ifdef JPFF */
+/*         printf("***Expand until/while %d\n", csound->inZero); */
+/* #endif */
         current = expand_until_statement(csound, current,
                                          typeTable, current->type==WHILE_TOKEN);
-
+        //print_tree(csound, "until/while", current);
         if (previous != NULL) {
           previous->next = current;
         }
@@ -1900,7 +1900,7 @@ TREE* verify_tree(CSOUND * csound, TREE *root, TYPE_TABLE* typeTable)
         break;
       case ENDIN_TOKEN:
       case UDOEND_TOKEN:
-        csound->inZero = 1;
+        csound->inZero = 1;     /* ****Is this right??????? */
         /* fall through */
       default:
         if (!verify_opcode(csound, current, typeTable)) {
@@ -1963,11 +1963,10 @@ void csound_orcerror(PARSE_PARM *pp, void *yyscanner,
     uint64_t files = csound_orcget_locn(yyscanner);
     if (UNLIKELY(*p=='\0' || *p=='\n')) line--;
     //printf("LINE: %d\n", line);
-
-    csound->Message(csound, Str("\nerror: %s  (token \"%s\")"),
+    csoundErrorMsg(csound, Str("\nerror: %s  (token \"%s\")\n"),
                     str, csound_orcget_text(yyscanner));
     do_baktrace(csound, files);
-    csound->Message(csound, Str(" line %d:\n>>>"), line);
+    csoundErrorMsg(csound, Str(" line %d:\n >>> "), line);
     while ((ch=*--p) != '\n' && ch != '\0');
     do {
       ch = *++p;
@@ -1976,9 +1975,11 @@ void csound_orcerror(PARSE_PARM *pp, void *yyscanner,
       if (ch=='#' && strncmp(p,"sline ",6)) {
         p+=7; while (isdigit(*p)) p++;
       }
-      else csound->Message(csound, "%c", ch);
+      else {
+          csoundErrorMsg(csound, "%c", ch);
+      }
     } while (ch != '\n' && ch != '\0');
-    csound->Message(csound, " <<<\n");
+      csoundErrorMsg(csound, " <<<\n");
 }
 
 void do_baktrace(CSOUND *csound, uint64_t files)
@@ -1986,7 +1987,7 @@ void do_baktrace(CSOUND *csound, uint64_t files)
     while (files) {
       unsigned int ff = files&0xff;
       files = files >>8;
-      csound->Message(csound, Str(" from file %s (%d)\n"),
+      csoundErrorMsg(csound, Str(" from file %s (%d),"),
                       csound->filedir[ff], ff);
     }
 }
