@@ -50,3 +50,10 @@ typedef struct {
         OPDS   h;
         MYFLT  *ans;
 } GETSEED;
+
+typedef struct gauss{
+  OPDS h;
+  MYFLT *a, *mu, *sigma;
+  MYFLT z;
+  int flag;
+} GAUSS;
