@@ -55,7 +55,7 @@ typedef struct {
         FUNC *outftp, **ftp = p->ftp;                                   \
         MYFLT *chanblock = (MYFLT *)  csound->m_chnbp[chan]->ctl_val;   \
                                                                         \
-        if ((outftp = csound->FTnp2Find(csound, p->ioutfn)) != NULL)    \
+        if ((outftp = csound->FTnp2Finde(csound, p->ioutfn)) != NULL)    \
           p->outTable = outftp->ftable;                                 \
         while (j < 8) {                                                 \
             int32_t t = (int32_t) *sld->ifn;                                    \
@@ -111,7 +111,7 @@ typedef struct {
             default: /* TABLE */                                        \
               value = value; /* unchanged, value must be in the 0 to 1 range, */ \
               /*   representing the phase of the table            */    \
-              if (*sld->ifn > 0)   *ftp = csound->FTnp2Find(csound, sld->ifn); \
+              if (*sld->ifn > 0)   *ftp = csound->FTnp2Finde(csound, sld->ifn); \
             }                                                           \
             chanblock[*slnum++] =  (MYFLT)((int32_t)(value * f7bit + FL(0.5))); \
             min++; max++; ftp++; j++; sld++;                            \
@@ -269,7 +269,7 @@ static int32_t sliderTable64(CSOUND *csound, SLIDER64t *p) /* GAB */
       MYFLT *yt1 = p->yt1, *c1=p->c1, *c2=p->c2;                        \
                                                                         \
                                                                         \
-      if((outftp = csound->FTnp2Find(csound, p->ioutfn)) != NULL)       \
+      if((outftp = csound->FTnp2Finde(csound, p->ioutfn)) != NULL)       \
         p->outTable = outftp->ftable;                                   \
       while (j < n) {                                                   \
         int32_t t = (int32_t) *sld->ifn;                                        \
@@ -311,7 +311,7 @@ static int32_t sliderTable64(CSOUND *csound, SLIDER64t *p) /* GAB */
         default: /* TABLE */                                            \
           value = value; /* unchanged, value must be in the 0 to 1 range, */ \
           /* representing the phase of the table */                     \
-          if (*sld->ifn > 0)   *ftp = csound->FTnp2Find(csound, sld->ifn); \
+          if (*sld->ifn > 0)   *ftp = csound->FTnp2Finde(csound, sld->ifn); \
           if (UNLIKELY(value >= 1 || value < 0)) {                      \
             snprintf(sbuf, 120,                                         \
                     Str("sliderXtable: illegal initvalue at "           \
@@ -514,7 +514,7 @@ static int32_t sliderKawai_i(CSOUND *csound, SLIDERKAWAI *p)
         snprintf(sbuf, 120, Str("illegal initvalue at position n.%d"), j);
         return csound->InitError(csound, "%s", sbuf);
       }
-      if (*sld->ifn > 0)   *ftp++ = csound->FTnp2Find(csound, sld->ifn);
+      if (*sld->ifn > 0)   *ftp++ = csound->FTnp2Finde(csound, sld->ifn);
       else                 *ftp++ = NULL;
       value =  (*(sld++)->initvalue - *min) / (*max++ - *min);
       min++;
@@ -571,7 +571,7 @@ static int32_t ctrl7a_set(CSOUND *csound, CTRL7a *p)
     else p->ctlno = ctlno;
 
     if (*p->ifn > 0) {
-      if (UNLIKELY(((p->ftp = csound->FTnp2Find(csound, p->ifn)) == NULL)))
+      if (UNLIKELY(((p->ftp = csound->FTnp2Finde(csound, p->ifn)) == NULL)))
         p->flag = 0;  /* invalid ftable */
       else p->flag= 1;
     }
