@@ -107,7 +107,7 @@ static void log(CSOUND *csound, const char *format, ...) {
   va_list args;
   va_start(args, format);
   if (csound) {
-    if (csound->GetMessageLevel(csound) & WARNMSG)
+    if (csound->GetMessageLevel(csound) & CS_WARNMSG)
       csound->MessageV(csound, 0, format, args);
   } else {
     vfprintf(stdout, format, args);
@@ -117,7 +117,7 @@ static void log(CSOUND *csound, const char *format, ...) {
 
 static void warn(CSOUND *csound, const char *format, ...) {
   if (csound) {
-    if (csound->GetMessageLevel(csound) & WARNMSG) {
+    if (csound->GetMessageLevel(csound) & CS_WARNMSG) {
       va_list args;
       va_start(args, format);
       csound->MessageV(csound, CSOUNDMSG_WARNING, format, args);
