@@ -10,7 +10,7 @@ export const freeStringPtr = (wasm, ptr) => {
 };
 
 export const ptr2string = (wasm, stringPtr) => {
-  const { buffer } = wasm.exports.memory;
+  const { buffer } = wasm.wasi.memory;
   const intArray = new Uint8Array(buffer, stringPtr);
   const result = uint2String(intArray);
   return trimNull(result);
@@ -24,7 +24,7 @@ export const string2ptr = (wasm, string) => {
 
   const stringBuf = encoder.encode(string);
   const offset = wasm.exports.allocStringMem(stringBuf.length);
-  const { buffer } = wasm.exports.memory;
+  const { buffer } = wasm.wasi.memory;
   const outBuf = new Uint8Array(buffer, offset, stringBuf.length + 1);
   outBuf.set(stringBuf);
   return offset;
