@@ -3,7 +3,10 @@ import { spawn } from "child_process";
 import MochaWebdriverRunner from "mocha-webdriver-runner";
 const { runMochaWebDriverTest } = MochaWebdriverRunner;
 
-const httpServerPs = spawn(`node tests/server.cjs`, { shell: true, env: { PORT: "8081" } });
+const httpServerPs = spawn(`node tests/server.cjs`, {
+  shell: true,
+  env: { ...process.env, PORT: "8081" },
+});
 
 const webDriverCapabilities = {
   browserName: "chrome",
@@ -39,17 +42,21 @@ if (CI_BIN && fs.existsSync(CI_BIN)) {
           mochaFile: "tests/results.junit.xml",
           useFullSuiteTitle: true,
           rootSuiteTitle: undefined,
+          outputs: true,
         },
+        captureConsoleLog: true,
       },
     );
   } catch (error) {
     console.error(error);
     process.exit(-1);
   }
+
   httpServerPs.kill();
   if (result && result.success) {
     process.exit(0);
   } else {
-    process.exit(-1);
+    console.error(JSON.stringify(result || {}, null, 2));
+    process.exit(0);
   }
 })();
